<?php

	if ( ! class_exists( 'Redux' ) ) {
		return;
	}

	// This is your option name where all the Redux data is stored.
    $opt_name = "yourstore_option";

    $theme = wp_get_theme(); // For use with some settings. Not necessary.
   	$opt_prefix = 'yourstore';

    $args = array(
		// TYPICAL -> Change these values as you need/desire
		'opt_name'             => $opt_name,
		'disable_tracking'     => true,
		// This is where your data is stored in the database and also becomes your global variable name.
		'display_name'         => $theme->get( 'Name' ),
		// Name that appears at the top of your panel
		'display_version'      => $theme->get( 'Version' ),
		// Version that appears at the top of your panel
		'menu_type'            => 'menu',
		//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
		'allow_sub_menu'       => true,
		// Show the sections below the admin menu item or not
		'menu_title'           => esc_html__( 'Yourstore Options', 'yourstore' ),
		'page_title'           => esc_html__( 'Yourstore Options', 'yourstore' ),
		// You will need to generate a Google API key to use this feature.
		// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
		'google_api_key'       => '',
		// Set it you want google fonts to update weekly. A google_api_key value is required.
		'google_update_weekly' => false,
		// Must be defined to add google fonts to the typography module
		'async_typography'     => false,
		// Use a asynchronous font on the front end or font string
		//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
		'admin_bar'            => true,
		// Show the panel pages on the admin bar
		'admin_bar_icon'       => 'dashicons-portfolio',
		// Choose an icon for the admin bar menu
		'admin_bar_priority'   => 50,
		// Choose an priority for the admin bar menu
		'global_variable'      => '',
		// Set a different name for your global variable other than the opt_name
		'dev_mode'             => false,
		// Show the time the page took to load, etc
		'update_notice'        => true,
		// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
		'customizer'           => false,
		// Enable basic customizer support
		//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
		//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
		// OPTIONAL -> Give you extra features
		'page_priority'        => null,
		// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
		'page_parent'          => 'themes.php',
		// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
		'page_permissions'     => 'manage_options',
		// Permissions needed to access the options panel.
		'menu_icon'            => '',
		// Specify a custom URL to an icon
		'last_tab'             => '',
		// Force your panel to always open to a specific tab (by id)
		'page_icon'            => 'icon-themes',
		// Icon displayed in the admin panel next to your menu_title
		'page_slug'            => '',
		// Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
		'save_defaults'        => true,
		// On load save the defaults to DB before user clicks save or not
		'default_show'         => false,
		// If true, shows the default value next to each field that is not the default value.
		'default_mark'         => '',
		// What to print by the field's title if the value shown is default. Suggested: *
		'show_import_export'   => true,
		// Shows the Import/Export panel when not used as a field.
		// CAREFUL -> These options are for advanced use only
		'transient_time'       => 60 * MINUTE_IN_SECONDS,
		'output'               => true,
		// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
		'output_tag'           => true,
		// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
		// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
		// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
		'database'             => '',
		// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
		'use_cdn'              => true,
		// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
		// HINTS
		'hints'                => array(
			'icon'          => 'el el-question-sign',
			'icon_position' => 'right',
			'icon_color'    => 'lightgray',
			'icon_size'     => 'normal',
			'tip_style'     => array(
				'color'   => 'red',
				'shadow'  => true,
				'rounded' => false,
				'style'   => '',
			),
			'tip_position'  => array(
				'my' => 'top left',
				'at' => 'bottom right',
			),
			'tip_effect'    => array(
				'show' => array(
					'effect'   => 'slide',
					'duration' => '500',
					'event'    => 'mouseover',
				),
				'hide' => array(
					'effect'   => 'slide',
					'duration' => '500',
					'event'    => 'click mouseleave',
				),
			),
		)
	);


	Redux::setArgs( $opt_name, $args );

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Header Settings', 'yourstore' ),
		'id'               => 'header_settings',
		'desc'             => esc_html__( 'All header settings', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-website',
		'fields'           => array(
            array(
				'id'       => 'is_site_preloader',
				'type'     => 'switch',
				'title'    => esc_html__('Display preloader before page load', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable site preloader', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'yourstore_logo_autosize',
				'type'     => 'switch',
				'title'    => esc_html__('Logo Auto Size', 'yourstore'),
				'subtitle' => esc_html__('Enable/disable Logo Auto Size', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'yourstore_logo',
				'type'     => 'media',
				'url'       => true,
				'compiler'  => 'true',
                'desc'      => esc_html__('Basic media uploader with disabled URL input field.', 'yourstore'),
                        'subtitle'  => esc_html__('Add/Upload logo using the WordPress native uploader', 'yourstore'),

				'title'    => esc_html__( 'Site Logo', 'yourstore' ),
				'default'     => array(
					'url'       => YOURSTORE_THEME_URI . '/images/logo.png',
				),
			),
            array(
                'id'        => $opt_prefix.'-site-favicon',
                'type'      => 'media',
                'url'       => true,
                'title'     => esc_html__('Favicon URL', 'yourstore'),
                'compiler'  => 'true',
                'desc'      => esc_html__('Set favicon for your theme', 'yourstore'),
                'subtitle'  => esc_html__('Upload favicon for the theme', 'yourstore'),
                'default'   => array('url' => YOURSTORE_THEME_URI.'/images/favicon.ico'),
            ),
			array(
				'id'       => 'yourstore_header_type',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Site Header', 'yourstore' ),
				'subtitle' => esc_html__( 'Select which type of header you want to show', 'yourstore' ),
				'default'     => '1',
				'options' => array(
					'1' => array(
						'alt'   => 'Header One',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-01.png'
					), 
                    '2' => array(
						'alt'   => 'Header two',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-02.png'
					), 
                    '3' => array(
						'alt'   => 'Header three',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-03.png'
					), 
                    '4' => array(
						'alt'   => 'Header four',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-04.png'
					), 
                    '5' => array(
						'alt'   => 'Header five',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-05.png'
					), 
                    '6' => array(
						'alt'   => 'Header six',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-06.png'
					), 
                    '7' => array(
						'alt'   => 'Header seven',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-07.png'
					), 
                    '8' => array(
						'alt'   => 'Header eight',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-08.png'
					), 
                    '9' => array(
						'alt'   => 'Header nine',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/header-09.png'
					),
				)
			),
			array(
				'id'       => 'yourstore_header_bg',
				'type'     => 'media',
				'title'    => esc_html__( 'Header Background Image', 'yourstore' ),
				'default'     => array(),
			),
            array(
				'id'       => 'yourstore_header_auto_suggest_status',
				'type'     => 'switch',
				'title'    => esc_html__('Header Autosuggest Product Search', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Header Autosuggest Product Search', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'yourstore_header_ats_img_status',
				'type'     => 'switch',
				'title'    => esc_html__('Header Autosuggest Product Search With Image', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Header Autosuggest Product Search With Image', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'yourstore_header_auto_suggest_limit',
				'type'     => 'text',
				'title'    => esc_html__('Autosuggest Limit', 'yourstore'),
				'subtitle' => esc_html__('Set Autosuggest Results Limitation', 'yourstore'),
				'default'  => '10'
			),
			array(
				'id'       => 'yourstore_header_left_txt',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Header Left Text', 'yourstore' ),
				'subtitle' => esc_html__( 'It will show at top left.' , 'yourstore' ),
				'default'     => wp_kses(__('Default welcome msg!', 'yourstore'), array('i' => array( 'class' => array() ), 'a' => array('href' => array()))),
			),
			array(
				'id'       => 'mini_cart_bottom_border_only',
				'type'     => 'select',
				'title'    => esc_html__( 'Mini Cart Popup Border', 'yourstore' ),
				'subtitle' => esc_html__( 'At minicart only border bottom', 'yourstore' ),
				'default'     => 'off',
				'options' => array(
					'on' => esc_html__('Bottom Only', 'yourstore'),
        			'off' => esc_html__('All Side', 'yourstore'),
				)
			),
            array(
				'id'       => 'header_prod_compare_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Display Compare on header', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Compare on header', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'header_prod_wishlist_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Display Wishlist on header', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Wishlist on header', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'header_lang_enable',
				'type'     => 'switch',
				'title'    => esc_html__('Display language dropdown on header', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable language dropdown on header', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'header_currency_enable',
				'type'     => 'switch',
				'title'    => esc_html__('Display currency dropdown on header', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable currency dropdown on header', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
		)
	) );

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Blog Settings', 'yourstore' ),
		'id'               => 'blog_settings',
		'desc'             => esc_html__( 'These are really basic fields!', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-th-large',
		'fields'           => array(
			array(
				'id'       => 'yourstore_blog_grid_type',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Post Grid Style', 'yourstore' ),
				'subtitle' => esc_html__( 'Blog style grid or full-width', 'yourstore' ),
				'default'     => 'bl1',
				'options' => array(
					'bl1' => array(
						'alt'   => esc_html__('Fullwidth Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/blog-layout-1.png'
					),
					'bl2' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/blog-layout-2.png'
					),
                    'bl3' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/blog-layout-3.png'
					),
				)
			),
            array(
				'id'       => 'is_blog_sidebar_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Blog Sidebar', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable blog sidebar', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'is_single_blog_sidebar_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Single Blog Sidebar', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable single blog sidebar', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'yourstore_blog_author_bg',
				'type'     => 'media',
				'title'    => esc_html__( 'Author Bio Background Image', 'yourstore' ),
				'subtitle' => esc_html__( 'Author Bio background image at single blog post.', 'yourstore' ),
				'default'     => array(),
			),
		)
	));
	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Contact Page Settings', 'yourstore' ),
		'id'               => 'contact_settings',
		'desc'             => esc_html__( 'These are really basic fields!', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-th-large',
		'fields'           => array(
            array(
				'id'       => 'display_gmap_on_contact',
				'type'     => 'switch',
				'title'    => esc_html__('Show Google Map', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Google Map', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'gmap_latitude',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Latitude', 'yourstore'),
				'subtitle' => esc_html__('Set Google Map Latitude', 'yourstore'),
				'default'  => '40.6700'
			),
			array(
				'id'       => 'gmap_longitude',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Longitude', 'yourstore'),
				'subtitle' => esc_html__('Set Google Map Longitude', 'yourstore'),
				'default'  => '-73.9400'
			),
		)
	));


	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Typography', 'yourstore' ),
		'id'               => 'typography',
		'desc'             => esc_html__( 'Theme all font options', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-font',
		'fields'           => array(
			array(
				'id'       => 'body_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Body Typography', 'yourstore' ),
				'subtitle' => esc_html__( 'Select body font family, size, line height, color and weight.', 'yourstore' ),
				'text-align' => false,
				'subsets' => false,
				'default'     => array(
					'color'       => '#000',
					'font-weight'  => '400',
					'font-family' => 'Ubuntu',
					'google'      => true,
					'font-size'   => '16px',
					'line-height' => '22px'
				),
			),
			array(
				'id'       => 'page_title_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Page Title', 'yourstore' ),
				'subtitle' => esc_html__( 'Page title Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => false,
                'output' => array('h1','h2','h3','h4','h5','h6'),
				'default'     => array(
					'font-weight'  => '500',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
			array(
				'id'       => 'primary_menu_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Primary Menu', 'yourstore' ),
				'subtitle' => esc_html__( 'Primary Menu Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => false,
                'output' => array('#off-canvas-menu ul li .name a', '#header .mainMenu #primary-menu.navbar-nav a'),
				'default'     => array(
					'font-weight'  => '500',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
			array(
				'id'       => 'product_title_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Product Title', 'yourstore' ),
				'subtitle' => esc_html__( 'Product Title Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => true,
                'output' => array('.product__inside__name h2 a'),
				'default'     => array(
					'font-weight'  => '500',
                    'font-size'  => '16px',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
			array(
				'id'       => 'footer_widget_title_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Footer Widget Title', 'yourstore' ),
				'subtitle' => esc_html__( 'Footer Widget Title Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => false,
                'output' => array('footer .widget  h4'),
				'default'     => array(
					'font-weight'  => '500',
                    'font-size'  => '18px',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
			array(
				'id'       => 'footer_menu_widget_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Footer Menu Widget', 'yourstore' ),
				'subtitle' => esc_html__( 'Footer Menu Widget Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => true,
                'output' => array('footer .widget.widget_nav_menu ul li a'),
				'default'     => array(
					'font-weight'  => '500',
                    'font-size'  => '16px',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
			array(
				'id'       => 'footer_copyright_typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Footer Copyright', 'yourstore' ),
				'subtitle' => esc_html__( 'Footer Copyright Typography Settings', 'yourstore' ),
				'text-align' => false,
				'line-height' => false,
				'subsets' => false,
                'color' => false,
                'font-size' => true,
                'font-weight' => false,
                'output' => array('.footer-copyright', '.footer-copyright a'),
				'default'     => array(
					'font-size'  => '16px',
					'font-family' => 'Ubuntu',
					'google'      => true,
				),
			),
		)
	) );

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Woocommerce Settings', 'yourstore' ),
		'id'               => 'wc_settings',
		'desc'             => esc_html__( 'These are really basic fields!', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-shopping-cart-sign',
		'fields'           => array(
            array(
				'id'       => 'disable_shop',
				'type'     => 'switch', 
				'title'    => esc_html__('Enable Catalog Mode', 'yourstore'),
				'subtitle' => esc_html__('Enable Catalog Mode', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Yes', 'yourstore'),
				'off'	   => esc_html__('No', 'yourstore'),
			),
			array(
				'id'       => 'products_per_page',
				'type'     => 'spinner', 
				'title'    => esc_html__('Products per page', 'yourstore'),
				'subtitle' => esc_html__('Number of products you want to show at shop and category page', 'yourstore'),
				'default'  => 9,
			),
            array(
				'id'       => 'shop_page_grid_column',
				'type'     => 'select',
				'title'    => esc_html__( 'Product grid columns for shop page', 'yourstore' ),
				'subtitle' => esc_html__( 'Set Product grid columns for shop page', 'yourstore' ),
				'default'     => '3',
				'options' => array(
					'2' => esc_html__('2 Columns', 'yourstore'),
					'3' => esc_html__('3 Columns', 'yourstore'),
					'4' => esc_html__('4 Columns', 'yourstore'),
					'5' => esc_html__('5 Columns', 'yourstore'),
					'6' => esc_html__('6 Columns', 'yourstore'),
					'9' => esc_html__('9 Columns', 'yourstore'),
				)
			),
            array(
				'id'       => 'yourstore_shop_layout',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Shop Layout', 'yourstore' ),
				'subtitle' => esc_html__( 'Select shop page layout', 'yourstore' ),
				'default'     => '1',
				'options' => array(
					'1' => array(
						'alt'   => 'Left Sidebar',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/left.jpg'
					), 
                    '2' => array(
						'alt'   => 'Full',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/no.jpg'
					), 
                    '3' => array(
						'alt'   => 'Right Sidebar',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/right.jpg'
					),
					 '4' => array(
						'alt'   => 'Both Sidebar',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/both.jpg'
					),
				)
			),
            array(
				'id'       => 'product_img_swap',
				'type'     => 'switch', 
				'title'    => esc_html__('Enable Product Grid Images Swap', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Product Grid Images Swap', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'show_brand_in_product',
				'type'     => 'switch', 
				'title'    => esc_html__('Enable/Disable Brand', 'yourstore'),
				'subtitle' => esc_html__('Enable/Disable Brand', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'is_product_share_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Display Product Share', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Product Share on product page', 'yourstore'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
            array(
				'id'       => 'addthis_widget',
				'type'     => 'textarea',
				'title'    => esc_html__('AddThis Widget Markup', 'yourstore'),
				'subtitle' => esc_html__('Set AddThis Widget Markup', 'yourstore'),
				'default'  => '<script type="text/javascript" src="//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-552765a6695754de" async="async"></script><div class="addthis_sharing_toolbox"></div>'
			),
            array(
				'id'       => 'yourstore_product_sidebar_layout',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Product Sidebar Layout', 'yourstore' ),
				'subtitle' => esc_html__( 'Select product page sidebar layout', 'yourstore' ),
				'default'     => '3',
				'options' => array(
                    '2' => array(
						'alt'   => 'Full',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/no.jpg'
					), 
                    '3' => array(
						'alt'   => 'Right Sidebar',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/right.jpg'
					),
				)
			),
            array(
				'id'       => 'yourstore_product_page_layout',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Product Page Layout', 'yourstore' ),
				'subtitle' => esc_html__( 'Select product page layout', 'yourstore' ),
				'default'     => '2',
				'options' => array(
					'1' => array(
						'alt'   => 'Layout 1',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/product-menu-img-1.png'
					), 
                    '2' => array(
						'alt'   => 'Layout 2',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/product-menu-img-2.png'
					),
                    '3' => array(
						'alt'   => 'Layout 3',
						'img'   => YOURSTORE_THEME_URI.'/images/admin/product-menu-img-3.png'
					),
				)
			),
            
		)
	));

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Popup Settings', 'yourstore' ),
		'id'               => 'popup_settings',
		'desc'             => esc_html__( 'Popup for email subscription', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-website-alt',
		'fields'           => array(
			array(
				'id'       => 'is_popup_enable',
				'type'     => 'switch', 
				'title'    => esc_html__('Popup', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable popup on site', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'popup_title',
				'type'     => 'text',
				'title'    => esc_html__('Popup Title', 'yourstore'),
				'subtitle' => esc_html__('Popup title which one will be shown at top of popup', 'yourstore'),
				'default'  => 'Newsletter signup'
			),
			array(
				'id'       => 'popup_subtitle',
				'type'     => 'editor',
				'title'    => esc_html__('Popup Sub-Title', 'yourstore'),
				'subtitle' => esc_html__('It will be shown at just below title', 'yourstore'),
				'default'  => 'Subscribe to the <strong style="color:#da2127;text-decoration: underline;">yourstore</strong> mailing list to receive updates on new arrivals, offers and other discount information.'
			),
			array(
				'id'       => 'popup_nomore_text',
				'type'     => 'text',
				'title'    => esc_html__('Don\'t show it again', 'yourstore'),
				'subtitle' => esc_html__('Don\'t show it again checkbox title', 'yourstore'),
				'default'  => 'Don\'t show it again'
			),

			array(
				'id'       => 'popup_mc_form',
				'type'     => 'textarea',
				'title'    => esc_html__('MailChimp Form', 'yourstore'),
				'subtitle' => esc_html__('MailChimp form murkup', 'yourstore'),
				'default'  => ''
			),
			array(
				'id'       => 'popup_bg_img',
				'type'     => 'background',
				'title'    => esc_html__('Popup Background Image', 'yourstore'),
				'subtitle' => esc_html__('Popup backgrund settings', 'yourstore'),
				'default'  => array(
					'background-color' => '#ffffff'
				)
			),
		)
	) );

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Footer Settings', 'yourstore' ),
		'id'               => 'footer_settings',
		//'desc'             => esc_html__( 'These are really basic fields!', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-share',
		'fields'           => array(
 

			array(
				'id'       => 'is_secondary_footer',
				'type'     => 'switch', 
				'title'    => esc_html__('Secondary Footer Sidebar', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Secondary sidebar', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'yourstore_footer_style',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Footer Widget Style', 'yourstore' ),
				'subtitle' => esc_html__( 'Footer Widget Style', 'yourstore' ),
				'default'     => 'cols4',
				'options' => array(
					'cols3' => array(
						'alt'   => esc_html__('Fullwidth Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/footer-col3.png'
					),
					'cols4' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/footer-col4.png'
					),
					'cols5' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/footer-col5.png'
					),
					'cols4_2' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/footer-col4-2.png'
					),
					'cols5_2' => array(
						'alt'   => esc_html__('Grid Style', 'yourstore'),
						'img'   => YOURSTORE_THEME_URI.'/images/admin/footer-col5-2.png'
					),
				)
			),
            array(
				'id'       => 'yourstore_footer_copyright',
				'type'     => 'textarea',
				'title'    => esc_html__('Copyright', 'yourstore'),
				'subtitle' => esc_html__('Copyright Text', 'yourstore'),
				'default'  => '<a href="'.home_url('/').'"><span>Your</span>Store</a> &copy; 2016 . All Rights Reserved.'
			),
			array(
				'id'       => 'footer_map',
				'type'     => 'switch', 
				'title'    => esc_html__('Show Contact Map In Footer', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Show Contact Map In Footer', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),
			array(
				'id'       => 'gmap_api_key',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Api Key', 'yourstore'),
				'subtitle' => esc_html__('Set Google Map Api Key', 'yourstore'),
				'default'  => ''
			),
			array(
				'id'       => 'gmap_latitude',
				'type'     => 'text',
				'title'    => esc_html__('latitude', 'yourstore'),
				'subtitle' => esc_html__('The latitude  to center the map ', 'yourstore'),
				'default'  => '40.6700'
 
			),
			array(
				'id'       => 'gmap_longitude',
				'type'     => 'text',
				'title'    => esc_html__('longitude', 'yourstore'),
				'subtitle' => esc_html__('The longitude  to center the map ', 'yourstore'),
				'default'  => '-73.9400'
 
			),

			array(
				'id'       => 'enable_payment_logo',
				'type'     => 'switch', 
				'title'    => esc_html__('Show Payment  Logo In Footer', 'yourstore'),
				'subtitle' => esc_html__('Enable or Disable Payment Logo In Footer', 'yourstore'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'yourstore'),
				'off'	   => esc_html__('Disable', 'yourstore'),
			),


			array(
				'id'       => 'footer_paymnet_logo',
				'type'     => 'media',
				 'url'       => true,
				'title'    => esc_html__( 'Footer Logo', 'yourstore' ),
				'subtitle' => esc_html__( 'Add Mayment Logo Of the Site', 'yourstore' ),
				'default'     => array(
					'url'       => YOURSTORE_THEME_URI.'/images/icon-payment.png',
				),
			),

                 
//			array(
//				'id'       => 'yourstore_footer_phn_label',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Phone Label', 'yourstore' ),
//				'subtitle' => esc_html__( 'Footer phone number label', 'yourstore' ),
//				'default'     => 'Our Phones:'
//			),
//			array(
//				'id'       => 'yourstore_footer_phn_number',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Phone Number', 'yourstore' ),
//				'subtitle' => esc_html__( 'Footer phone number', 'yourstore' ),
//				'default'     => '44 800 123 45 67   /  38 240 123 45 89'
//			),
//			array(
//				'id'       => 'yourstore_footer_email',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Email/Contact Page URL', 'yourstore' ),
//				'subtitle' => esc_html__( 'Email address or Contact page link here', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_map_url',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Google Map URL', 'yourstore' ),
//				'subtitle' => esc_html__( 'Your address google map link', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_facebook',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Facebook URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_twitter',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Twitter URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_google_plus',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Google Plus URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_youtube',
//				'type'     => 'text',
//				'title'    => esc_html__( 'YouTube URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_pinterest',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Pinterest URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_flickr',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Flickr URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_dribbble',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Dribbble URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_behance',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Behance URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_instagram',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Instagram URL', 'yourstore' ),
//				'default'     => '#'
//			),
//			array(
//				'id'       => 'yourstore_footer_social_git',
//				'type'     => 'text',
//				'title'    => esc_html__( 'Git URL', 'yourstore' ),
//				'default'     => '#'
//			),
		)
	));
	Redux::setSection( $opt_name, array(
		'title'            => esc_html__( 'Extra Settings', 'yourstore' ),
		'id'               => 'extra_settings',
		'desc'             => esc_html__( 'These are really basic fields!', 'yourstore' ),
		'customizer_width' => '400px',
		'icon'             => 'el el-share',
		'fields'           => array(
			array(
				'id'       => 'extra_css',
				'type'     => 'ace_editor',
				'title'    => esc_html__( 'Extra CSS', 'yourstore' ),
				'subtitle' => esc_html__( 'Extra CSS just after theme styles', 'yourstore' ),
				'mode' => 'css'
			),
		)
	));

       for($o = 0.0, $n = 0; $o <= 1.0; $o += 0.1, $n++)
                $opacities[$n] = $o;
            
            $hours = $months = $seconds = $days = array();
        
            for($n=0;$n<12;$n++){
                $timestamp = mktime(0, 0, 0, $n+1);
                $months[$n] = date('F',$timestamp);            
            }        
            for($n=1;$n<32;$n++){
                $days[$n] = $n;
            }
            for($n = 0; $n < 24; $n++){
                $hours[$n] = $n;
            }
            for($n = 0; $n < 60; $n++){            
                $seconds[$n] = $n;
            }
            
Redux::setSection( $opt_name, array(
                'icon'      => 'el-icon-cogs',
                'title'     => esc_html__('Maintenance', 'yourstore'),
                'fields'    => array(
                    array(
                        'id'        => $opt_prefix.'-maintenance-mode-status',
                        'type'      => 'switch',
                        'title'     => esc_html__('Enable/Disable maintenance mode', 'yourstore'),
                        'subtitle'  => '',
                        'default'   => 0,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled',
                    ),
                    array(
                        'id'        => $opt_prefix.'-maintenance-bg',
                        'type'      => 'background',
                        'title'     => esc_html__('Maintenance page content background', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '',
                        'background-attachment'      => true,
                     
                    ),                    
                    array(
                        'id'        => $opt_prefix.'-maintenance-page-title',
                        'type'      => 'text',
                        'title'     => esc_html__('Page Title', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '',
                        'default'      => 'Coming soon',                        
                    ),
                    array(
                        'id'        => $opt_prefix.'-maintenance-title',
                        'type'      => 'text',
                        'title'     => esc_html__('Title before countdown area', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '',
                        'default'      => 'Currently we are under construction',                        
                    ),
                    array(
                        'id'        => $opt_prefix.'-maintenance-subtitle',
                        'type'      => 'text',
                        'title'     => esc_html__('Sub-title before countdown area', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '',
                        'default'      => 'We will be back in:',                        
                    ),
                    array(
                        'id'        => $opt_prefix.'-maintenance-countdown-status',
                        'type'      => 'switch',
                        'title'     => esc_html__('Enable/Disable countdown', 'yourstore'),
                        'subtitle'  => '',
                        'default'   => 1,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled',
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-year',
                        'type'      => 'text',
                        'title'     => esc_html__('Countdown Year', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => esc_html__('Insert Year', 'yourstore'),
                        'default'      => (int)date('Y')+1,                        
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-month',
                        'type'      => 'select',
                        'title'     => esc_html__('Countdown Month', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '0', 
                        'options' => $months,
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-day',
                        'type'      => 'select',
                        'title'     => esc_html__('Countdown Day', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '1', 
                        'options' => $days,
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-hour',
                        'type'      => 'select',
                        'title'     => esc_html__('Countdown Hour', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '0', 
                        'options' => $hours,
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-minutes',
                        'type'      => 'select',
                        'title'     => esc_html__('Countdown Minutes', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '0', 
                        'options' => $seconds,
                    ),
                    array(
                        'id'        => $opt_prefix.'-countdown-seconds',
                        'type'      => 'select',
                        'title'     => esc_html__('Countdown Seconds', 'yourstore'),
                        'subtitle'  => '',
                        'desc'      => '', 
                        'default'      => '0', 
                        'options' => $seconds,
                    ),
                   
        	)
	));
/**
 * @abstract Remove redux about page from Tools
 */
add_action( 'admin_menu', 'yourstore_remove_redux_menu', 20);
function yourstore_remove_redux_menu() {
    remove_submenu_page('tools.php', 'redux-about');
}