<?php
add_action('widgets_init', 'yourstore_latest_post');

function yourstore_latest_post()
{
    register_widget('YourStore_Latest_Post');
}

class YourStore_Latest_Post extends WP_Widget
{

    private $defaults = array();

    function __construct()
    {
        include_once YOURSTORE_FREAMWORK_DIRECTORY . 'widgets/get-the-image.php';

        $this->defaults = array(
            'title' => esc_html__('Latest Post', 'yourstore'),
            'number' => 5,
            'layout_type' => 'slider',
            'per_row' => 3,
        );
        parent::__construct('widget_latest_posts_tab', esc_html__('YourStore Latest Posts', 'yourstore'));
    }
    /* ----------------------------------------
      update()
      ----------------------------------------

     * Function to update the settings from
     * the form() function.

     * Params:
     * - Array $new_instance
     * - Array $old_instance
      ---------------------------------------- */

    function update($new_instance, $old_instance)
    {
        $defaults = $this->defaults;
        $instance = $old_instance;
        $instance['title'] = esc_attr($new_instance['title']);
        $instance['number'] = intval($new_instance['number']);
        $instance['layout_type'] = esc_attr($new_instance['layout_type']);
        $instance['per_row'] = intval($new_instance['per_row']);
        $instance['first_full'] = $new_instance['first_full'];

        return $instance;
    }

// End update()

    /* ----------------------------------------
      form()
      ----------------------------------------

     * The form on the widget control in the
     * widget administration area.

     * Make use of the get_field_id() and 
     * get_field_name() function when creating
     * your form elements. This handles the confusing stuff.

     * Params:
     * - Array $instance
      ---------------------------------------- */

    function form($instance)
    {

        $instance = wp_parse_args((array) $instance, $this->defaults);
        $layout_type = strip_tags($instance['layout_type']);
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';

        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'yourstore'); ?></label>
            <input type="text" name="<?php echo esc_attr($this->get_field_name('title')); ?>"  value="<?php echo esc_attr($title); ?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" />
        </p>
        <p>
            <label for="<?php print esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('Number of posts:', 'yourstore'); ?>
                <input class="widefat" id="<?php print esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo isset($instance['number']) ? esc_attr($instance['number']) : ''; ?>" />
            </label>
        </p>

        <p><label for="<?php echo esc_attr($this->get_field_id('layout_type')); ?>"><?php esc_html_e('Layout type', 'yourstore'); ?></label>
            <select id="<?php echo esc_attr($this->get_field_id('layout_type')); ?>" name="<?php echo esc_attr($this->get_field_name('layout_type')); ?>">
                <option value="slider" <?php selected($layout_type, 'slider'); ?>><?php esc_html_e('slider', 'yourstore'); ?></option>
                <option value="list" <?php selected($layout_type, 'list'); ?>><?php esc_html_e('grid', 'yourstore'); ?></option>
            </select></p>



        <?php
    }

// End form()

    function widget($args, $instance)
    {


        $instance = wp_parse_args((array) $instance, $this->defaults);

        extract($args);

        $number = isset($instance['number']) ? $instance['number'] : 5;
        //  $per_row = isset($instance['per_row']) ? $instance['per_row'] : 1;


        $title = $instance['title'];
        $layout_type = $instance['layout_type'];
        echo wp_kses_post($before_widget);
        /* If a title was input by the user, display it. */
        if (!empty($title)) {
            print wp_kses_post($before_title . apply_filters('widget_title', $title, $instance, $this->id_base) . $after_title);
        }
        if ($layout_type == 'list') {
            $this->yourstore_all_latest_posts_sidebar_list($number, $title);
        } else {
            $this->yourstore_all_latest_posts_sidebar_slider($number, $title);
        }
        echo wp_kses_post($after_widget);
    }

    function yourstore_all_latest_posts_list($number = 3, $title = null)
    {

        $query_args = array(
            'posts_per_page' => $number,
            'no_found_rows' => true,
            'post_status' => 'publish',
            'ignore_sticky_posts' => true
        );

        ?>
        <!-- title --> 


        <!-- /title -->
        <!-- carousel-new -->  
        <?php
        $sds_r = new WP_Query($query_args);

        ?>
        <?php
        $sds_r_i = 0;
        $first_gone = false;
        if ($sds_r->have_posts()):
            while ($sds_r->have_posts()) : $sds_r->the_post();

                $sds_r_i++;

                ?>
                <!-- slide-->

                <!--  -->							
                <div class="recent-post-box recent-post-col row">
                    <div class="col-xs-6 col-sm-12 col-md-6">
                        <a href="<?php the_permalink() ?>">
                            <span class="figure">
                                <?php
                                $imageArgs = array(
                                    'width' => 370,
                                    'height' => 283,
                                    'image_class' => 'thumbnail',
                                    'format' => 'array',
                                    'default_image' => '',
                                    'size' => 'post-thumbnail'
                                );


                                $postImage = pptwj_get_the_image($imageArgs, get_the_ID());

                                ?>
                                <?php if (isset($postImage['src']) && !empty($postImage['src'])): ?>
                                    <img src="<?php echo esc_url($postImage['src']); ?>" alt="<?php echo esc_attr($postImage['alt']); ?>" /> 
                <?php endif; ?>
                                <span class="figcaption label-top-left">
                                    <span>
                                        <b><?php echo get_the_date("j"); ?></b>
                                        <em><?php echo get_the_date("M"); ?></em>
                                    </span>
                                </span>
                            </span>									
                        </a>
                    </div>
                    <div class="col-xs-6 col-sm-12 col-md-6">
                        <div class="recent-post-box__text">
                            <h4><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
                            <div class="author"><?php esc_html_e('by', 'yourstore'); ?> <b><?php the_author() ?></b></div>
                            <p>
                <?php echo substr(get_the_excerpt(), 0, 80) ?>
                            </p>
                        </div>
                    </div>
                </div>

                <!-- /slide -->

                <?php
            endwhile;
        endif;
        wp_reset_postdata();

        ?>

        <?php
    }

    function yourstore_all_latest_posts($number = 5, $title = null, $random = '')
    {

        $query_args = array(
            'posts_per_page' => $number,
            'no_found_rows' => true,
            'post_status' => 'publish',
            'ignore_sticky_posts' => true
        );

        ?>
        <!-- title -->
        <div class="title-with-button">
            <div class="carousel-products__button pull-right">
                <span class="btn-prev"></span>
                <span class="btn-next"></span>
            </div>
            <?php if(!empty($title)){?>
            <h2 class="text-center title-under"><?php echo wp_kses_post($title);?></h2>
            <?php }?>
        </div>
        <!-- /title -->
        <!-- carousel-new -->
        <div class="carousel-products row" id="postsCarouselCustom_<?php echo esc_attr($random) ?>">

            <?php
            $sds_r = new WP_Query($query_args);

            ?>
            <?php
            $sds_r_i = 0;
            $first_gone = false;
            if ($sds_r->have_posts()):
                while ($sds_r->have_posts()) : $sds_r->the_post();

                    $sds_r_i++;

                    ?>
                    <!-- slide-->
                    <div class="col-sm-3 col-xl-6">
                        <!--  -->
                        <div class="recent-post-box">
                            <div class="col-lg-12 col-xl-6">
                                <a href="<?php the_permalink() ?>">
                                    <span class="figure">
                                        <?php
                                        the_post_thumbnail();
                                        ?>
                                        <span class="figcaption label-top-left">
                                            <span>
                                                <b><?php echo get_the_date("j"); ?></b>
                                                <em><?php echo get_the_date("M"); ?></em>
                                            </span>
                                        </span>
                                    </span>
                                </a>
                            </div>
                            <div class="col-lg-12 col-xl-6">
                                <div class="recent-post-box__text">
                                    <h4 class="entry-title <?php /*echo esc_attr($title_class);*/ ?>"><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
                                    <div class="author"><?php esc_html_e('by', 'yourstore'); ?> <b><?php the_author() ?></b></div>
                                        <?php echo substr(get_the_excerpt(), 0, 80) ?>
                                    <a class="link-commet" href="<?php echo esc_url(get_permalink()) ?>">
                                        <span class="icon icon-message"></span>
                                        <?php
                                        printf(_nx('0 comment(s)', '%1$s comment(s)', get_comments_number(), 'comments title', 'yourstore'), number_format_i18n(get_comments_number()));
                                        ?>
                                    </a>


                                </div>
                            </div>
                        </div>
                        <!-- / -->
                    </div>
                    <!-- /slide -->

                    <?php
                endwhile;
            endif;
            wp_reset_postdata();

            ?>
        </div>
        <?php
    }

    function yourstore_all_latest_posts_sidebar_slider($number = 5, $title = null)
    {

        $query_args = array(
            'posts_per_page' => $number,
            'no_found_rows' => true,
            'post_status' => 'publish',
            'ignore_sticky_posts' => true
        );
        $rand = rand(000000, 999999);

        ?>
        <!-- title -->

        <!-- /title -->
        <!-- carousel-new -->
        <!-- /title -->
        <div class="carousel-products row layout-none-xl" id="postsCarousel_<?php echo esc_attr($rand) ?>">

            <?php
            $sds_r = new WP_Query($query_args);

            ?>
            <?php
            $sds_r_i = 0;
            $first_gone = false;
            if ($sds_r->have_posts()):
                while ($sds_r->have_posts()) : $sds_r->the_post();

                    $sds_r_i++;

                    ?>
                    <!-- slide-->
                    <div class="recent-post-box">
                        <div class="col-lg-12 col-xl-12">
                            <a href="<?php the_permalink() ?>">
                                <span class="figure">
                                    <?php
                                    $imageArgs = array(
                                        'width' => 370,
                                        'height' => 283,
                                        'image_class' => 'thumbnail',
                                        'format' => 'array',
                                        'default_image' => '',
                                        'size' => 'post-thumbnail'
                                    );


                                    $postImage = pptwj_get_the_image($imageArgs, get_the_ID());

                                    ?>
                <?php if (isset($postImage['src']) && !empty($postImage['src'])): ?>
                                        <img src="<?php echo esc_url($postImage['src']); ?>" alt="<?php echo esc_attr($postImage['alt']); ?>">
                <?php endif; ?>         

                                    <span class="figcaption label-top-left">
                                        <span>
                                            <b><?php echo get_the_date("j"); ?></b>
                                            <em><?php echo get_the_date("M"); ?></em>
                                        </span>
                                    </span>
                                </span>
                            </a>
                        </div>
                        <div class="col-lg-12 col-xl-12">
                            <div class="recent-post-box__text">
                                <h4><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
                                <div class="author"><?php esc_html_e('by', 'yourstore'); ?> <b><?php the_author() ?></b></div>
                                <p>
                                        <?php echo substr(get_the_excerpt(), 0, 80) ?>
                                </p>
                                <a class="link-commet" href="<?php echo esc_url(get_permalink()) ?>"><span class="icon icon-message "></span><span class="number"><?php
                        printf(_nx('0', '%1$s', get_comments_number(), 'comments title', 'yourstore'), number_format_i18n(get_comments_number()));

                        ?></span> comment(s)</a>
                            </div>
                        </div>
                    </div>
                    <!-- / --> 
                    <!-- /slide-->
                    <?php
                endwhile;
            endif;
            wp_reset_postdata();

            ?>
        </div> 
        <div class="carousel-products__button button-bottom carousel-products__button_aside">
            <span class="btn-prev"></span>
            <span class="btn-next"></span>        
        </div>
        <?php
    }

    function yourstore_all_latest_posts_sidebar_list($number = 5, $title = null)
    {

        $query_args = array(
            'posts_per_page' => $number,
            'no_found_rows' => true,
            'post_status' => 'publish',
            'ignore_sticky_posts' => true
        );
        $rand = rand(000000, 999999);

        ?>
        <!-- title -->

        <!-- /title -->
        <!-- carousel-new --> 
        <!-- /title -->
        <div>

            <?php
            $sds_r = new WP_Query($query_args);

            ?>
            <?php
            $sds_r_i = 0;
            $first_gone = false;
            if ($sds_r->have_posts()):
                while ($sds_r->have_posts()) : $sds_r->the_post();

                    $sds_r_i++;

                    ?>
                    <!-- slide-->
                    <div class="recent-post-box">
                        <div class="col-lg-12 col-xl-6">
                            <a href="<?php the_permalink() ?>">
                                <span class="figure">
                                    <?php
                                    $imageArgs = array(
                                        'width' => 370,
                                        'height' => 283,
                                        'image_class' => 'thumbnail',
                                        'format' => 'array',
                                        'default_image' => '',
                                        'size' => 'post-thumbnail'
                                    );


                                    $postImage = pptwj_get_the_image($imageArgs, get_the_ID());

                                    ?>
                <?php if (isset($postImage['src']) && !empty($postImage['src'])): ?>
                                        <img src="<?php echo esc_url($postImage['src']); ?>" alt="<?php echo esc_attr($postImage['alt']); ?>" /> <?php endif; ?>
                                    <span class="figcaption label-top-left">
                                        <span>
                                            <b><?php echo get_the_date("j"); ?></b>
                                            <em><?php echo get_the_date("M"); ?></em>
                                        </span>
                                    </span>
                                </span>									
                            </a>
                        </div>
                        <div class="col-lg-12 col-xl-6">
                            <div class="recent-post-box__text">
                                <h4><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
                                <div class="author"><?php esc_html_e('by', 'yourstore'); ?> <b><?php the_author() ?></b></div>
                                <p>
                <?php echo substr(get_the_excerpt(), 0, 80) ?>
                                </p>
                            </div>
                        </div>
                    </div>

                    <!-- / --> 
                    <!-- /slide-->
                <?php
            endwhile;
        endif;
        wp_reset_postdata();

        ?>
        </div>
        <?php
    }
}

// End Class

