<?php
/**
 * Testimonials Widget
 */
class Testimonial_Widget extends WP_Widget {
    public function __construct() {
        $widget_ops = array( 'classname' => 'testimonial_widget', 'description' => 'Display testimonial post type' );
        parent::__construct( 'testimonial_widget', 'Testimonials', $widget_ops );
    }
 
    public function widget( $args, $instance ) {
        if(function_exists('get_testimonial')){
            extract( $args );
            $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
            $posts_per_page = (int) $instance['posts_per_page'];
            $orderby = strip_tags( $instance['orderby'] );
            $testimonial_id = ( null == $instance['testimonial_id'] ) ? '' : strip_tags( $instance['testimonial_id'] );

            echo wp_kses_post($before_widget);

            if ( ! empty( $title ) )
                echo wp_kses_post($before_title . $after_title);

            echo get_testimonial( $posts_per_page, $orderby, $testimonial_id,$title ); 
            echo wp_kses_post($after_widget);
        }
    }
 
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['orderby'] = strip_tags( $new_instance['orderby'] );
        $instance['testimonial_id'] = ( null == $new_instance['testimonial_id'] ) ? '' : strip_tags( $new_instance['testimonial_id'] );
 
        return $instance;
    }
 
    public function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'posts_per_page' => '1', 'orderby' => 'none', 'testimonial_id' => null ) );
        $title = strip_tags( $instance['title'] );
        $posts_per_page = (int) $instance['posts_per_page'];
        $orderby = strip_tags( $instance['orderby'] );
        $testimonial_id = ( null == $instance['testimonial_id'] ) ? '' : strip_tags( $instance['testimonial_id'] );
        ?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', 'yourstore')?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>
 
        <p><label for="<?php echo esc_attr($this->get_field_id( 'posts_per_page' )); ?>"><?php esc_html_e('Number of Testimonials:', 'yourstore')?> </label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'posts_per_page' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'posts_per_page' )); ?>" type="text" value="<?php echo esc_attr( $posts_per_page ); ?>" />
        </p>
 
        <p><label for="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>"><?php esc_html_e('Order By:', 'yourstore')?></label>
        <select id="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'orderby' )); ?>">
            <option value="none" <?php selected( $orderby, 'none' ); ?>><?php esc_html_e('None', 'yourstore')?></option>
            <option value="ID" <?php selected( $orderby, 'ID' ); ?>><?php esc_html_e('ID', 'yourstore')?></option>
            <option value="date" <?php selected( $orderby, 'date' ); ?>><?php esc_html_e('Date', 'yourstore')?></option>
            <option value="modified" <?php selected( $orderby, 'modified' ); ?>><?php esc_html_e('Modified', 'yourstore')?></option>
            <option value="rand" <?php selected( $orderby, 'rand' ); ?>><?php esc_html_e('Random', 'yourstore')?></option>
        </select></p>
 
        <p><label for="<?php echo esc_attr($this->get_field_id( 'testimonial_id' )); ?>"><?php esc_html_e('Testimonial ID', 'yourstore')?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'testimonial_id' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'testimonial_id' )); ?>" type="text" value="<?php print $testimonial_id; ?>" /></p>
        <?php
    }
}
 
add_action( 'widgets_init', 'register_testimonials_widget' );
/**
 * Register widget
 *
 * This functions is attached to the 'widgets_init' action hook.
 */
function register_testimonials_widget() {
    register_widget( 'Testimonial_Widget' );
}