<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package yourstore-theme
 */

if ( ! function_exists( 'yourstore_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since Twenty Fifteen 1.0
 */
function yourstore_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'yourstore' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'yourstore' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'yourstore' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;


if ( ! function_exists( 'yourstore_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function yourstore_posted_on() {

	echo '	<div class="post__title_block">
			<div class="pull-left">
				<time>
				';
	echo '<span>'.get_the_date('j') .'</span>' .get_the_date("M")  ;
					 
	echo '</time>';
	echo '		</div>										
			<div class="pull-left">
				<h2 class="post__title text-uppercase">';
	echo  the_title() .'</h2>
				<div class="post__meta">
					<span class="post__meta__item">';

	echo  esc_html__( 'by', 'yourstore' ).' <b>'. get_the_author().'</b></span>';
	echo'				<span class="post__meta__item">
						<span class="icon icon-message"></span>';
	printf( _nx( '(01) <span class="yourstore_hide_on_grid">Comment</span>', '(%1$s) <span class="yourstore_hide_on_grid">Comments</span>', get_comments_number(), 'comments title', 'yourstore' ), number_format_i18n( get_comments_number() ) );
			 
	echo '		</span>';
						 
	$categories_list = get_the_category_list( esc_html__( ', ', 'yourstore' ) );
	if ( $categories_list && yourstore_categorized_blog() ) {
		printf('<span class="post__meta__item">');
		printf('<span class="icon icon-folder"></span>');
		printf( '<span class="cat-links">' . esc_html__( '%1$s', 'yourstore' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		printf('</span>');
	}
	$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'yourstore' ) );
		if ( $tags_list ) {
			printf('<span class="post__meta__item">');
			printf('<span class="icon icon-bookmark_border"></span>');
			printf( '<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Tags', 'Used before tag names.', 'yourstore' ),
				$tags_list
			);
			printf('</span>');
		}	
 
	echo '		</div>
			</div>									
		</div>
		';
 

}
endif;

if ( ! function_exists( 'yourstore_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function yourstore_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'yourstore' ) );
		if ( $categories_list && yourstore_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'yourstore' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'yourstore' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'yourstore' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'yourstore' ), esc_html__( '1 Comment', 'yourstore' ), esc_html__( '% Comments', 'yourstore' ) );
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'yourstore' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function yourstore_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'yourstore_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'yourstore_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so yourstore_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so yourstore_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in yourstore_categorized_blog.
 */
function yourstore_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'yourstore_categories' );
}
add_action( 'edit_category', 'yourstore_category_transient_flusher' );
add_action( 'save_post',     'yourstore_category_transient_flusher' );


function yourstore_entry_meta(){

	

	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';


		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			get_the_date(),
			esc_attr( get_the_modified_date( 'c' ) ),
			get_the_modified_date()
		);

		printf( '<span class="framwork posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark"><i class="fa fa-calendar">&nbsp;&nbsp;</i>%3$s<span></span></a></span>',
			_x( 'Posted on', 'Used before publish date.', 'yourstore' ),
			esc_url( get_permalink() ),
			$time_string
		);
	}
	?>

	 
		<span class="framwork-commnet-number">
			<a href="<?php echo esc_url( get_permalink() ) ?>">
				&nbsp;<i class="fa fa-comment-o"></i>&nbsp;
				<?php 
				printf( _nx( '1 <span class="yourstore_hide_on_grid">Comment</span>', '%1$s <span class="yourstore_hide_on_grid">Comments</span>', get_comments_number(), 'comments title', 'yourstore' ), number_format_i18n( get_comments_number() ) );
				?>
			</a>
		</span>

		<?php if(function_exists('yourstore_love_it')) { echo yourstore_love_it(); } ?> 

		<?php echo yourstore_share_buttons(); ?>


<?php
	if ( 'post' == get_post_type() ) {
		if ( is_singular() || is_multi_author() ) {
			printf( '<span class="byline"><span class="author vcard"><span class="screen-reader-text">%1$s </span><a class="url fn n" href="%2$s">%3$s</a></span></span>',
				_x( 'Author', 'Used before post author name.', 'yourstore' ),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				get_the_author()
			);
		}

		

		$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'yourstore' ) );
		
	}

	if ( is_attachment() && wp_attachment_is_image() ) {
		// Retrieve attachment metadata.
		$metadata = wp_get_attachment_metadata();

		printf( '<span class="full-size-link"><span class="screen-reader-text">%1$s </span><a href="%2$s">%3$s &times; %4$s</a></span>',
			_x( 'Full size', 'Used before full size attachment link.', 'yourstore' ),
			esc_url( wp_get_attachment_url() ),
			$metadata['width'],
			$metadata['height']
		);
	}





}

function yourstore_share_buttons()
{
	global $post;
	?>
	<span class="framwork-share-this">	
		<i class="fa fa-share-alt"></i>
		<span  class="framwork-share-this-popup">
			<ul>
				<li><a onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url( get_permalink() ) ?>"><i class="fa fa-facebook"></i></a></li>
				<li><a onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" href="https://twitter.com/home?status=<?php echo esc_html( get_the_title() ) ?> - <?php echo esc_url( get_permalink() ) ?>"><i class="fa fa-twitter"></i></a></li>
				<li><a onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" href="https://plus.google.com/share?url=<?php echo esc_url( get_permalink() ) ?>"><i class="fa fa-google-plus"></i></a></li>
				<li><a onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url( get_permalink() ) ?>&media=<?php echo esc_url(yourstore_get_post_thumb_src($post->ID)); ?>&description="><i class="fa fa-pinterest"></i></a></li>
			</ul>
		</span>
	</span>
	<?php
}

function yourstore_get_post_thumb_src($postID)
{
	return wp_get_attachment_url( get_post_thumbnail_id($postID) );;
}

function yourstore_post_thumbnail($thumb_size = 'post-thumbnail') {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}

	global $yourstore_option;
	
	$yourstore_grid_styled_post = ((isset($yourstore_option['yourstore_blog_grid_type']) && $yourstore_option['yourstore_blog_grid_type'] == 'on') || (isset($_GET['grid']) && $_GET['grid'] == 'on')) ? true : false;

	$yourstore_grid_thumb_size = ($yourstore_grid_styled_post && !is_sticky()) ? 'yourstore-grid-thumb' : $thumb_size;

	if ( is_singular() ) :
	?>

	<div class="post-thumbnail">
		<?php the_post_thumbnail('full', array( 'alt' => get_the_title() )); ?>
	</div><!-- .post-thumbnail -->

    <?php else :
    if(is_home()){ 
        $yourstore_grid_thumb_size = 'full';
    }?>

	<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
		<?php
			the_post_thumbnail( $yourstore_grid_thumb_size, array( 'alt' => get_the_title() ) );
		?>
	</a>

	<?php endif; // End is_singular()
}


function yourstore_page_menu( $args = array() ) {
    $defaults = array('sort_column' => 'menu_order, post_title', 'menu_class' => 'menu', 'echo' => true, 'link_before' => '', 'link_after' => '');
    $args = wp_parse_args( $args, $defaults );
 
    $menu = '';
 
    $list_args = $args;
 
    // Show Home in the menu
    if ( ! empty($args['show_home']) ) {
        if ( true === $args['show_home'] || '1' === $args['show_home'] || 1 === $args['show_home'] )
            $text = esc_html__('Home', 'yourstore');
        else
            $text = $args['show_home'];
        $class = '';
        if ( is_front_page() && !is_paged() )
            $class = 'class="current_page_item"';
        $menu .= '<li ' . $class . '><a href="' . home_url( '/' ) . '">' . $args['link_before'] . $text . $args['link_after'] . '</a></li>';
        // If the front page is a page, add it to the exclude list
        if (get_option('show_on_front') == 'page') {
            if ( !empty( $list_args['exclude'] ) ) {
                $list_args['exclude'] .= ',';
            } else {
                $list_args['exclude'] = '';
            }
            $list_args['exclude'] .= get_option('page_on_front');
        }
    }
 
    $list_args['echo'] = false;
    $list_args['title_li'] = '';
    $menu .= str_replace( array( "\r", "\n", "\t" ), '', wp_list_pages($list_args) );
 
    if ( $menu ){
        $menu = '<ul class="' . esc_attr($args['menu_class']) . '">' . $menu . '</ul>';
    }
 

    if ( $args['echo'] )
        print wp_kses_post($menu);
    else
        return $menu;
}





// Related post function
function yourstore_related_posts() {
	?>
	
	<?php
	$post_categories = wp_get_post_terms( get_the_ID(), 'category' );
	$post_tags = wp_get_post_terms( get_the_ID(), 'post_tag' );


	$all_related_posts = array();

	$not___in = array();
	$not___in[] = get_the_ID();

	foreach ($post_categories as $post_categorie) {

		$rp_args = array(
			'posts_per_page' => 4,
			'exclude' => get_the_ID(),
			'cat' => $post_categorie->term_id,
			'post__not_in' => $not___in
		);

		$related_posts_temp = new WP_Query( $rp_args );

		if($related_posts_temp->have_posts()){
			$all_related_posts[] = $related_posts_temp;
		}
	}

	foreach ($post_tags as $post_tag) {
		$rp_args = array(
			'posts_per_page' => 4,
			'exclude' => get_the_ID(),
			'tag_id' => $post_tag->term_id,
			'post__not_in' => $not___in
		);

		$related_posts_temp = new WP_Query( $rp_args );

		if($related_posts_temp->have_posts()){
			$all_related_posts[] = $related_posts_temp;
		}
		
	}

	$already_in = array();
	
	if(count($all_related_posts)):
		$pcount = 0;
	?>
	<h3 class="title-related-post"><?php esc_html_e('Related Posts', 'yourstore'); ?></h3>
	<div class="yourstore-single-post-slider-box">	
		<ul class="yourstore-rated-post-slider-item">
			<?php foreach($all_related_posts as $related_posts): ?>
				<?php if ($related_posts->have_posts()): ?>
					<?php while ( $related_posts->have_posts() ) : $related_posts->the_post(); ?>
						<?php

						if(!isset($already_in[get_the_ID()])): 
							$pcount++;
							$already_in[get_the_ID()] = get_the_ID();
						
						?>
						<li>
							<div class="yourstore-single-post-box framework-grid-post framework-per-single-post-no-thumb">
								<div class="entry_categories <?php if( has_post_thumbnail() ) { echo "entry_categories-per-single-post"; } ?>">
									<?php
									$categories = get_the_category();
									if (count($categories)) {
										foreach ($categories as $categorie) {
											?>
											<span><a href="<?php echo esc_url(get_term_link($categorie)); ?>"><?php echo esc_html($categorie->cat_name); ?></a></span>
											<?php
										}
									}
									?>
								</div>
								<?php if ( has_post_thumbnail() ): ?>
									<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
										<?php the_post_thumbnail( 'yourstore-grid-thumb', array( 'alt' => get_the_title() ) ); ?>
									</a>
								<?php endif; ?>
								<div class="yourstore-single-post-meta-box entry-meta">
									<?php yourstore_entry_meta(); ?>
								</div>
								<h4 class="title-yourstore-single-post"><?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?></h4>	
							</div>
						</li>
						<?php endif; ?>
						<?php if ($pcount >= 6) { break; } ?>
					<?php endwhile; ?>
				<?php endif; ?>
				<?php if ($pcount >= 6) { break; } ?>
			<?php endforeach; ?>
			<?php wp_reset_postdata(); ?>
		</ul>	
	</div>
<?php
	endif;
}

if ( ! function_exists( 'yourstore_get_option' ) ) {
	function yourstore_get_option( $id ){
		global $yourstore_option;

		if (isset($yourstore_option[$id])) {
			return $yourstore_option[$id];
		}

		return '';
	}
}

if ( ! function_exists( 'yourstore_get_yith_compare' ) ) {
	function yourstore_get_yith_compare(){
		global $yith_woocompare;

		return $yith_woocompare;
	}
}


if ( ! function_exists( 'yourstore_wpml_wc') ) {
	function yourstore_wpml_wc(){
		global $woocommerce_wpml;

		return $woocommerce_wpml;
	}
}

if ( ! function_exists( 'yourstore_wpml') ) {
	function yourstore_wpml(){
		global $sitepress;

		return $sitepress;
	}
}
$sds_post_comment_count = 0;

function yourstore_comment($comment, $args, $depth) {

	global $sds_post_comment_count;
    $max_depth = $args['max_depth'];
    
    $liclass = ( ++$sds_post_comment_count % 2 == 0 ) ? 'even' : 'odd';
    ?>
    <li class="<?php echo esc_attr($liclass . " depth-{$depth}") ?>">
    	<div class="media-body">
    		<?php echo get_avatar($comment->user_id, 100, '', $comment->comment_author); ?>
    	<div class="yourstore-author-comments-meta">

        <div itemtype="http://schema.org/UserComments" itemscope="" itemprop="comment" id="comment-<?php echo esc_attr($comment->comment_ID) ?>">

            <div class="media-title">

	            <div class="reply pull-right link">
					<?php
					$arr = array('reply_text' => esc_html__('Reply', 'yourstore'));

					comment_reply_link(array_merge($arr, array('depth' => $depth, 'max_depth' => $max_depth)));
					?>
				</div>
				<span class="username"><?php esc_html_e( 'by', 'yourstore' ); ?> <b><?php echo esc_html($comment->comment_author); ?></b></span>
                <time itemprop="commentTime" class="ln-comment-time">
                <span class="icon icon-access_time"></span>
                <?php echo esc_html(date(get_option('date_format'), strtotime($comment->comment_date))); ?>

                <?php printf("<small>".esc_html__("at %s", 'yourstore')."</small>", date(get_option('time_format'), strtotime($comment->comment_date))); ?>
                
                </time>

            </div>
            <p itemprop="media-content"><?php echo get_comment_text($comment->comment_ID); ?></p>
            </div>


        </div>
        </div>
    <?php
}