<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer).
 * will need to copy the new files to your theme to maintain compatibility. We try to do this.
 * as little as possible, but it does happen. When this occurs the version of the template file will.
 * be bumped and the readme will list any important changes.
 *
 * @see 	    http://docs.woothemes.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

get_header( 'shop' ); ?>

	<?php
		/**
		 * woocommerce_before_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 */
//		do_action( 'woocommerce_before_main_content' );
    $yourstore_option = yourstore_get_options();
    $design = $yourstore_option['yourstore_shop_layout'];
    $leftbar = $rightbar = $main = '';

    if (isset($_GET['layout']) && is_numeric($_GET['layout'])) 
   		$design = $_GET['layout'];

    switch ( $design){

        case '4':
            $rightbar = 'col-md-3 col-lg-3 col-xl-2 hidden-xs hidden-sm collection-list';
            $leftbar = 'col-md-3 col-lg-3 col-xl-2 collection-list';
            $main = 'col-md-6 col-lg-6 col-xl-8';
            break;
        case '3':
            $rightbar = 'col-md-4 col-lg-3 col-xl-2 hidden-xs hidden-sm collection-list';
            $main = 'col-md-8 col-lg-9 col-xl-10';
            break;

        case '1':
            $leftbar = 'col-md-4 col-lg-3 col-xl-2 collection-list';
            $main = 'col-md-8 col-lg-9 col-xl-10';
            break;

        default:
            $main = 'col-md-12 col-lg-12 col-xl-12';
            break;

    }
    // need to work here. introduce sidebars and main columns
	?>
<section class="breadcrumbs">
	<div class="container">
        <div class="breadcrumb breadcrumb--ys pull-left">
        <?php
        if ( is_plugin_active( 'wordpress-seo/wp-seo.php' ) && function_exists('yoast_breadcrumb') ) {
            yoast_breadcrumb('','');
        }
        ?>
        </div>
	</div>
</section>
<div id="pageContent">
    <section class="content">
        <div class="container">
            <div class="row">
                <?php 
                if($leftbar){
                    echo '<div id="leftColumn" class="'.esc_attr($leftbar).'">';
                    get_sidebar('shop-left');
                    echo '</div>';
                }
                ?>
                <div id="centerColumn" class="<?php echo esc_attr($main)?>">
                <?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
                    <div class="title-box">
                        <h2 class="text-center text-uppercase title-under"><?php woocommerce_page_title(); ?></h2>
                    </div>
                <?php endif; ?>

		<?php
			/**
			 * woocommerce_archive_description hook.
			 *
			 * @hooked woocommerce_taxonomy_archive_description - 10
			 * @hooked woocommerce_product_archive_description - 10
			 */
			do_action( 'woocommerce_archive_description' );
		?>
		<div class="divider"></div>
		<div class="row"><?php woocommerce_product_subcategories(); ?></div>

		<?php if ( have_posts() ) : ?>

			<?php
				/**
				 * woocommerce_before_shop_loop hook.
				 *
				 * @hooked woocommerce_result_count - 20
				 * @hooked woocommerce_catalog_ordering - 30
				 */
				do_action( 'woocommerce_before_shop_loop' );
			?>
<div class="columns-<?php echo $yourstore_option['shop_page_grid_column'] ?>">
			<?php woocommerce_product_loop_start(); ?>

				

				<?php while ( have_posts() ) : the_post(); ?>

					<?php wc_get_template_part( 'content', 'product' ); ?>

				<?php endwhile; // end of the loop. ?>

			<?php woocommerce_product_loop_end(); ?>
</div>
			<?php
				/**
				 * woocommerce_after_shop_loop hook.
				 *
				 * @hooked woocommerce_pagination - 10
				 */
				do_action( 'woocommerce_after_shop_loop' );
			?>

		<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

			<?php wc_get_template( 'loop/no-products-found.php' ); ?>

		<?php endif; ?>
                </div> <!-- main column -->
                <?php 
                if($rightbar){
                    echo '<div id="rightColumn" class="'.esc_attr($rightbar).'">';
                    get_sidebar('shop-right');
                    echo '</div>';
                }
                ?>
	<?php
		/**
		 * woocommerce_after_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
		 */
//		do_action( 'woocommerce_after_main_content' );
	?>

        <?php
            /**
             * woocommerce_sidebar hook.
             *
             * @hooked woocommerce_get_sidebar - 10
             */
    //		do_action( 'woocommerce_sidebar' );
        ?>
            </div><!-- end .row -->
        </div><!-- end .container -->
    </section><!-- end .content -->
</div><!-- end .content -->
<?php get_footer( 'shop' ); ?>
