<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer).
 * will need to copy the new files to your theme to maintain compatibility. We try to do this.
 * as little as possible, but it does happen. When this occurs the version of the template file will.
 * be bumped and the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
?>

<?php do_action( 'woocommerce_before_mini_cart' ); ?>
    <div class="dropdown-menu cart-content dropdown-menu--xs-full slide-from-top <?php echo isset($args['list_class']) ? $args['list_class'] :''; ?>" role="menu">
        <div class="container">
	<?php if ( ! WC()->cart->is_empty() ) : ?>
            <div class="cart__top"><?php _e('Recently added item(s)','yourstore')?></div>
            <a href="#" class="icon icon-close cart__close"><span><?php _e('CLOSE','yourstore')?></span></a>
            <ul>
		<?php
        do_action( 'woocommerce_before_mini_cart_contents' );
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {

					$product_name  = apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key );
					$thumbnail     = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
					$product_price = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                    $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );

					?>
                        <li class="cart__item">
                        <?php 

                           /* echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                                        '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
                                                        esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
                                                        __( 'Remove this item', 'woocommerce' ),
                                                        esc_attr( $product_id ),
                                                        esc_attr( $_product->get_sku() )
                                                    ), $cart_item_key );*/
                        ?>

                            <div class="cart__item__image pull-left">
                                <?php if ( ! $_product->is_visible() ) { ?>
                                    <?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail )?>
                                <?php } else { ?>
                                    <a href="<?php echo esc_url( $product_permalink ); ?>">
                                        <?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail )?></a>
                                <?php } ?>
                            </div>


                        <?php //echo WC()->cart->get_item_data( $cart_item ); ?>

                        <?php //echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>
                    



                            <div class="cart__item__control">
                                <div class="cart__item__delete"><a class="icon icon-delete"  aria-label="<?php echo __( 'Remove this item', 'yourstore' ) ?>" 
                                    data-product_id="<?php echo esc_attr( $product_id ); ?>" 
                                    data-product_sku="<?php echo esc_attr( $_product->get_sku())?>" 
                                    href="<?php echo esc_url( WC()->cart->get_remove_url( $cart_item_key ) )?>">
                                    <span><?php _e('Delete','yourstore')?></span></a></div>
                            </div>



                            <div class="cart__item__info">
                                <div class="cart__item__info__title">
                                    <?php if ( ! $_product->is_visible() ) { ?>
                                        <h2 class="title-center"><?php echo wp_kses_post($product_name); ?></h2>
                                    <?php } else { ?>
                                        <h2 class="title-center"><a href="<?php  echo esc_url( $product_permalink ); ?>"><?php echo wp_kses_post($product_name); ?></a></h2>
                                    <?php } ?>
                                </div>
                                <div class="cart__item__info__price"><span class="info-label"><?php _e('Price:','yourstore')?></span><span><?php print $product_price?></span></div>
                                <div class="cart__item__info__qty"><span class="info-label"><?php _e('Qty:','yourstore')?> &times;<?php print $cart_item['quantity']?></span></div>															
                            </div>
                        </li>
					<?php
				}
			}
            do_action( 'woocommerce_mini_cart_contents' );
		?>
                </ul>
                <div class="cart__bottom">
                    <div class="cart__total"><?php _e('Cart subtotal:','yourstore')?> <span> <?php echo WC()->cart->get_cart_subtotal(); ?></span>&nbsp;&nbsp;<?php _e('Total:','yourstore')?> <span><?php echo WC()->cart->get_cart_total(); ?></span></div>
                    <a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="btn btn--ys btn-checkout"><?php _e('Checkout', 'yourstore') ?> <span class="icon icon--flippedX icon-reply"></span></a>
                    <a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="btn btn--ys"><span class="icon icon-shopping_basket"></span> <?php _e('View Cart', 'yourstore') ?></a>

                <!-- <p class="woocommerce-mini-cart__buttons buttons"><?php do_action( 'woocommerce_widget_shopping_cart_buttons' ); ?></p> -->
                </div>

	<?php else : ?>
            <div class="cart__top"><?php _e( 'Your shopping cart is empty!', 'yourstore' ); ?></div>
            <a href="#" class="icon icon-close cart__close"><span><?php _e('CLOSE','yourstore')?></span></a>
	<?php endif; ?>

        </div><!-- end .container-->
    </div><!--  end .mini-cart-info -->  

<?php if ( ! WC()->cart->is_empty() ) : ?>

    <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>



<?php endif; ?>
    
<?php do_action( 'woocommerce_after_mini_cart' ); ?>



